import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

import com.itextpdf.text.Document;
import com.itextpdf.text.DocumentException;
import com.itextpdf.text.Element;
import com.itextpdf.text.Font;
import com.itextpdf.text.Image;
import com.itextpdf.text.ImgTemplate;
import com.itextpdf.text.PageSize;
import com.itextpdf.text.Phrase;
import com.itextpdf.text.pdf.Barcode39;
import com.itextpdf.text.pdf.ColumnText;
import com.itextpdf.text.pdf.PdfReader;
import com.itextpdf.text.pdf.PdfWriter;
import com.itextpdf.text.pdf.PdfImportedPage;
import com.itextpdf.text.pdf.PdfContentByte;
import com.itextpdf.text.pdf.PdfTemplate;

public class HelloWorldItext {

	/**
	 * @see https://api.itextpdf.com/iText5/java/5.5.10/
	 * @see https://kb.itextpdf.com/home/it5kb/faq/how-to-add-text-to-an-image
	 */
	private static String inep = "32081014";
	private static String nome = "ESCOLA MUNICIPAL DE ENSINO FUNDAMENTAL EDUCACAO RURAL CAMPONESA CONJUNTO FAMILIAR AGOSTINHO PARTELLI";
	private static String modelFile = "ModeloDE.pdf";
	private static String outFile = "EscolaDE.pdf";
	private static float fsize = 8.0f;
	private static float flead = 1.15f;
	
	/// text box dimensions and location
	private static int llx = 25;
	private static int lly = 323;
	private static int urx = 375;
	private static int ury = 358;
	/// barcode location (x0,y0)
	private static int llbcx = 410;
	private static int llbcy = 322;
	/// barcode image scale
	private static float barScale = 130f;

	public static void main(String[] args)   {
		
		Font fonte = new Font(Font.FontFamily.HELVETICA,fsize,Font.NORMAL);
		Phrase escola = new Phrase(inep + " - " + nome, fonte);
		try {
			// create and open output file
			Document document = new Document(PageSize.A5.rotate(),0,0,0,0);
			PdfWriter writer = PdfWriter.getInstance(document, new FileOutputStream(outFile));
			document.open();
			document.addAuthor("OBMEP");
			document.addCreationDate();
			document.addCreator("text.itextpdf.com");
			document.addTitle("Documento de Envio de Cartões");
			
			// import base page (pg. 1) as image
			PdfReader reader = new PdfReader(modelFile);
			PdfImportedPage page = writer.getImportedPage(reader, 1); // first page
			Image instance = Image.getInstance(page);
			
			// add base page image as background
			PdfContentByte cb = writer.getDirectContentUnder();
			PdfTemplate template = cb.createTemplate(instance.getScaledWidth(), instance.getScaledHeight());
			template.addImage(instance, instance.getScaledWidth(), 0, 0, instance.getScaledHeight(), 0, 0); // new image position at (0,0)
			
			// add barcode
			Barcode39 barcode39 = new Barcode39();
			barcode39.setCode(inep);
			Image barra = barcode39.createImageWithBarcode(cb, null, null); // null means default color
			barra.scaleToFit(barScale, barScale);
			template.addImage(barra, barra.getScaledWidth(), 0, 0, barra.getScaledHeight(), llbcx, llbcy); // new image position at (bcx,bcy)

			// add text
			ColumnText ct = new ColumnText(template);
			ct.setSimpleColumn(llx, lly, urx, ury, fsize + flead, Element.ALIGN_LEFT);
			ct.setText(escola);
			ct.go();

			// add barcode + text + background to document and save
			document.add(Image.getInstance(template));
			document.close();
			writer.close();
		} catch (DocumentException e) {
			e.printStackTrace();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
}
